@@ -82,6 +82,13 @@ enum TGAType {
 #define TGA_XMPP_TAGID 0x7002 // Xmp packet preceded by "xMPP" string
 #define TGA_ICCP_TAGID 0x7003 // Icc profile preceded by "iCCP" string
 
+/*
+ * Maximum size of a tag in the developer area.
+ *
+ * TGA is a 32-bit format so, a metadata should not be greater than some MB.
+ */
+#define DEV_TAG_MAX_SIZE (32 * 1024 * 1024)
+
 /** Tga Header. */
 struct TgaHeader {
     uchar id_length = 0;
@@ -610,11 +617,7 @@ static bool LoadTGA(QIODevice *dev, const TgaHeader &tga, QImage &img)
     // Read palette.
     if (info.pal) {
         QList<QRgb> colorTable;
-#if QT_VERSION < QT_VERSION_CHECK(6, 8, 0)
-        colorTable.resize(tga.colormap_length);
-#else
         colorTable.resizeForOverwrite(tga.colormap_length);
-#endif
 
         if (tga.colormap_size == 32) {
             char data[4]; // BGRA
@@ -988,16 +991,12 @@ bool TGAHandler::writeRGBA(const QImage &image)
 {
     auto format = image.format();
     const bool hasAlpha = image.hasAlphaChannel();
-#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
-    auto cs = image.colorSpace();
     auto tcs = QColorSpace();
+    auto cs = image.colorSpace();
     if (cs.isValid() && cs.colorModel() == QColorSpace::ColorModel::Cmyk && image.format() == QImage::Format_CMYK8888) {
         format = QImage::Format_RGB32;
         tcs = QColorSpace(QColorSpace::SRgb);
     } else if (hasAlpha && image.format() != QImage::Format_ARGB32) {
-#else
-    if (hasAlpha && image.format() != QImage::Format_ARGB32) {
-#endif
         format = QImage::Format_ARGB32;
     } else if (!hasAlpha && image.format() != QImage::Format_RGB32) {
         format = QImage::Format_RGB32;
@@ -1240,6 +1239,10 @@ bool TGAHandler::readMetadata(QImage &image)
             if (!dev->seek(f.offset)) {
                 return false;
             }
+            if (f.size > DEV_TAG_MAX_SIZE) {
+                qCWarning(LOG_TGAPLUGIN) << "readMetadata: the size of TAG" << f.tagId << "is larger than" << (DEV_TAG_MAX_SIZE/1024/1024) << "MiB, so it will be ignored";
+                continue;
+            }
             if (f.tagId == TGA_EXIF_TAGID) {
                 auto ba = dev->read(f.size);
                 if (ba.startsWith(QByteArray("eXif"))) {
@@ -1344,7 +1347,7 @@ bool TGAHandler::canRead(QIODevice *device)
 
     TgaHeader tga;
     if (!peekHeader(device, tga)) {
-        qCWarning(LOG_TGAPLUGIN) << "TGAHandler::canRead() error while reading the header";
+        qCDebug(LOG_TGAPLUGIN) << "TGAHandler::canRead() error while reading the header";
         return false;
     }
 
